@@ -29,14 +29,14 @@ def main():
 
     result = source[source.apply(not_exists, axis = 1)]
     print("The following are not present in target schema:")
-    print(result)
+    print(result.to_string())
     print(f"Target schema has less {len(result)} (table_name,column_name) than source schema")
-    result = result.to_html()
-    print("Generating report")
-    output = open("/output.html","w")
-    result = schema_compare.TEMPLATE.replace("{{body}}",result)
-    output.write(result)
-    output.close()
+    #result = result.to_html()
+    #print("Generating report")
+    #output = open("/output.html","w")
+    #result = schema_compare.TEMPLATE.replace("{{body}}",result)
+    #output.write(result)
+    #output.close()
 
 if __name__ == "__main__":
     main()
